==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/sk-SK/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Potvrdiť hromadné odstránenie majetku',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Nižšie skontrolujte zoznam majetku na odstránenie. Po odstránení je možné tieto majetky obnoviť, nebudú už ale priradené k žiadnym používateľom, ku ktorým sú momentálne priradení.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Chystáte sa odstrániť :asset_count majetky.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Hromadná úprava majetku',
    'bulk_update_help'	=> 'Tento formulár umožňuje hromadnú úpravu majetku. Vyplňte iba položky, ktoré chcete zmeniť. Akékoľvek prázdne položky zostanú nezmenené. ',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Odovzdané',
    'checkout_date'		=> 'Dátum odovzdania',
    'checkin_date'		=> 'Dátum prijatia',
    'checkout_to'		=> 'Odovzdať',
    'cost'				=> 'Kúpna cena',
    'create'			=> 'Pridať majetok',
    'date'				=> 'Dátum nákupu',
    'depreciation'	    => 'Odpisovanie',
    'depreciates_on'	=> 'Plne odpísaný',
    'default_location'	=> 'Povodná lokalita',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Dátum EOL',
    'eol_rate'			=> 'Miera EOL',
    'expected_checkin'  => 'Očakávaný dátum prijatia',
    'expires'			=> 'Exspiruje',
    'fully_depreciated'	=> 'Plne odpísaný',
    'help_checkout'		=> 'Ak si prajete priradiť tento majetok okamžite, zvoľte možnosť "Pripravený na odovzdanie" z vyššie dostupného zoznamu stavov. ',
    'mac_address'		=> 'MAC adresa',
    'manufacturer'		=> 'Výrobca',
    'model'				=> 'Model',
    'months'			=> 'mesiace/ov',
    'name'				=> 'Názov majetku',
    'notes'				=> 'Poznámky',
    'order'				=> 'Číslo objednávky',
    'qr'				=> 'QR kód',
    'requestable'		=> 'Používatelia môžu žiadať tento majetok',
    'select_statustype'	=> 'Vyberte typ stavu',
    'serial'			=> 'Sériové číslo',
    'status'			=> 'Stav',
    'tag'				=> 'Označenie majetku',
    'update'			=> 'Aktualizácia majetku',
    'warranty'			=> 'Záruka',
        'warranty_expires'		=> 'Koniec záruky',
    'years'				=> 'roky/ov',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Nepovinné informácie',
    'order_details'   => 'Informácie súvisiace s objednávkou'
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/sk-SK/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Potvrdiť hromadné odstránenie majetku',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Nižšie skontrolujte zoznam majetku na odstránenie. Po odstránení je možné tieto majetky obnoviť, nebudú už ale priradené k žiadnym používateľom, ku ktorým sú momentálne priradení.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Chystáte sa odstrániť :asset_count majetky.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Hromadná úprava majetku',
    'bulk_update_help'	=> 'Tento formulár umožňuje hromadnú úpravu majetku. Vyplňte iba položky, ktoré chcete zmeniť. Akékoľvek prázdne položky zostanú nezmenené. ',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Odovzdané',
    'checkout_date'		=> 'Dátum odovzdania',
    'checkin_date'		=> 'Dátum prijatia',
    'checkout_to'		=> 'Odovzdať',
    'cost'				=> 'Kúpna cena',
    'create'			=> 'Pridať majetok',
    'date'				=> 'Dátum nákupu',
    'depreciation'	    => 'Odpisovanie',
    'depreciates_on'	=> 'Plne odpísaný',
    'default_location'	=> 'Povodná lokalita',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Dátum EOL',
    'eol_rate'			=> 'Miera EOL',
    'expected_checkin'  => 'Očakávaný dátum prijatia',
    'expires'			=> 'Exspiruje',
    'fully_depreciated'	=> 'Plne odpísaný',
    'help_checkout'		=> 'Ak si prajete priradiť tento majetok okamžite, zvoľte možnosť "Pripravený na odovzdanie" z vyššie dostupného zoznamu stavov. ',
    'mac_address'		=> 'MAC adresa',
    'manufacturer'		=> 'Výrobca',
    'model'				=> 'Model',
    'months'			=> 'mesiace/ov',
    'name'				=> 'Názov majetku',
    'notes'				=> 'Poznámky',
    'order'				=> 'Číslo objednávky',
    'qr'				=> 'QR kód',
    'requestable'		=> 'Používatelia môžu žiadať tento majetok',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Vyberte typ stavu',
    'serial'			=> 'Sériové číslo',
    'status'			=> 'Stav',
    'tag'				=> 'Označenie majetku',
    'update'			=> 'Aktualizácia majetku',
    'warranty'			=> 'Záruka',
        'warranty_expires'		=> 'Koniec záruky',
    'years'				=> 'roky/ov',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Nepovinné informácie',
    'order_details'   => 'Informácie súvisiace s objednávkou'
];
